from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Uri:
	"""Uri commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("uri", core, parent)

	def get_cma(self) -> str:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:CMA \n
		Snippet: value: str = driver.configure.afRf.measurement.voip.uri.get_cma() \n
		Specifies the <user> part of the URI of the R&S CMA180 ('sip:<user>@<IP address>') . \n
			:return: address: String with user part
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:CMA?')
		return trim_str_response(response)

	def set_cma(self, address: str) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:CMA \n
		Snippet: driver.configure.afRf.measurement.voip.uri.set_cma(address = '1') \n
		Specifies the <user> part of the URI of the R&S CMA180 ('sip:<user>@<IP address>') . \n
			:param address: String with user part
		"""
		param = Conversions.value_to_quoted_str(address)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:CMA {param}')

	def get_ip(self) -> str:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:IP \n
		Snippet: value: str = driver.configure.afRf.measurement.voip.uri.get_ip() \n
		Specifies the <IP address> part of the URI of the DUT ('sip:<user>@<IP address>') . \n
			:return: address: IP address as string
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:IP?')
		return trim_str_response(response)

	def set_ip(self, address: str) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:IP \n
		Snippet: driver.configure.afRf.measurement.voip.uri.set_ip(address = '1') \n
		Specifies the <IP address> part of the URI of the DUT ('sip:<user>@<IP address>') . \n
			:param address: IP address as string
		"""
		param = Conversions.value_to_quoted_str(address)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:IP {param}')

	def get_port(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:PORT \n
		Snippet: value: int = driver.configure.afRf.measurement.voip.uri.get_port() \n
		No command help available \n
			:return: port: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:PORT?')
		return Conversions.str_to_int(response)

	def set_port(self, port: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:PORT \n
		Snippet: driver.configure.afRf.measurement.voip.uri.set_port(port = 1) \n
		No command help available \n
			:param port: No help available
		"""
		param = Conversions.decimal_value_to_str(port)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:PORT {param}')

	def get_user(self) -> str:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:USER \n
		Snippet: value: str = driver.configure.afRf.measurement.voip.uri.get_user() \n
		Specifies the <user> part of the URI of the DUT ('sip:<user>@<IP address>') . \n
			:return: user: String with user part
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:USER?')
		return trim_str_response(response)

	def set_user(self, user: str) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:USER \n
		Snippet: driver.configure.afRf.measurement.voip.uri.set_user(user = '1') \n
		Specifies the <user> part of the URI of the DUT ('sip:<user>@<IP address>') . \n
			:param user: String with user part
		"""
		param = Conversions.value_to_quoted_str(user)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:URI:USER {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Condition:
	"""Condition commands group definition. 3 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("condition", core, parent)

	@property
	def off(self):
		"""off commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_off'):
			from .Condition_.Off import Off
			self._off = Off(self._core, self._base)
		return self._off

	@property
	def pending(self):
		"""pending commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pending'):
			from .Condition_.Pending import Pending
			self._pending = Pending(self._core, self._base)
		return self._pending

	@property
	def on(self):
		"""on commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_on'):
			from .Condition_.On import On
			self._on = On(self._core, self._base)
		return self._on

	def clone(self) -> 'Condition':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Condition(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Obw:
	"""Obw commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("obw", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW:ENABle \n
		Snippet: value: bool = driver.configure.gprfMeasurement.acp.limit.obw.get_enable() \n
		Enables or disables the OBW limit checks. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW:ENABle \n
		Snippet: driver.configure.gprfMeasurement.acp.limit.obw.set_enable(enable = False) \n
		Enables or disables the OBW limit checks. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW:ENABle {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW \n
		Snippet: value: float = driver.configure.gprfMeasurement.acp.limit.obw.get_value() \n
		Configures an upper OBW limit. \n
			:return: limit: Range: 0 Hz to 8 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW?')
		return Conversions.str_to_float(response)

	def set_value(self, limit: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW \n
		Snippet: driver.configure.gprfMeasurement.acp.limit.obw.set_value(limit = 1.0) \n
		Configures an upper OBW limit. \n
			:param limit: Range: 0 Hz to 8 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(limit)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:LIMit:OBW {param}')



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ...Internal.Types import DataType
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqRecorder:
	"""IqRecorder commands group definition. 13 total commands, 5 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("iqRecorder", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .IqRecorder_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def talignment(self):
		"""talignment commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_talignment'):
			from .IqRecorder_.Talignment import Talignment
			self._talignment = Talignment(self._core, self._base)
		return self._talignment

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symbolRate'):
			from .IqRecorder_.SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._base)
		return self._symbolRate

	@property
	def bin(self):
		"""bin commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_bin'):
			from .IqRecorder_.Bin import Bin
			self._bin = Bin(self._core, self._base)
		return self._bin

	@property
	def reliability(self):
		"""reliability commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reliability'):
			from .IqRecorder_.Reliability import Reliability
			self._reliability = Reliability(self._core, self._base)
		return self._reliability

	def initiate(self, save_to_iq_file: enums.FileSave = None) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: driver.gprfMeasurement.iqRecorder.initiate(save_to_iq_file = enums.FileSave.OFF) \n
		Starts or continues the I/Q recorder measurement. \n
			:param save_to_iq_file: OFF | ON | ONLY Optional parameter, selecting whether the results are written to an I/Q file, to the memory or both. For selection of the I/Q file, see method RsCma.Configure.GprfMeasurement.IqRecorder.iqFile. OFF The results are only stored in the memory. ON The results are stored in the memory and in the file. ONLY The results are only stored in the file.
		"""
		param = ''
		if save_to_iq_file:
			param = Conversions.enum_scalar_to_str(save_to_iq_file, enums.FileSave)
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:IQRecorder {param}'.strip())

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: driver.gprfMeasurement.iqRecorder.abort() \n
		Stops the I/Q recorder measurement. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:IQRecorder')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: driver.gprfMeasurement.iqRecorder.abort_with_opc() \n
		Stops the I/Q recorder measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:IQRecorder')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: driver.gprfMeasurement.iqRecorder.stop() \n
		Pauses the I/Q recorder measurement. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:IQRecorder')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: driver.gprfMeasurement.iqRecorder.stop_with_opc() \n
		Pauses the I/Q recorder measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:IQRecorder')

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: value: List[float] = driver.gprfMeasurement.iqRecorder.read() \n
		Returns the I and Q amplitudes in the format specified by method RsCma.FormatPy.Base.data. For a detailed description of
		the data formats, see 'ASCII and Binary Data Formats'. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: iq_samples: For ASCII format: I/Q amplitudes in alternating order (I_1,Q_1, ...,I_n,Q_n) , as voltages. For REAL format: Binary block data consisting of the parts listed in the table below. There are no commas within this parameter."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:IQRecorder?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:IQRecorder \n
		Snippet: value: List[float] = driver.gprfMeasurement.iqRecorder.fetch() \n
		Returns the I and Q amplitudes in the format specified by method RsCma.FormatPy.Base.data. For a detailed description of
		the data formats, see 'ASCII and Binary Data Formats'. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: iq_samples: For ASCII format: I/Q amplitudes in alternating order (I_1,Q_1, ...,I_n,Q_n) , as voltages. For REAL format: Binary block data consisting of the parts listed in the table below. There are no commas within this parameter."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:IQRecorder?', suppressed)
		return response

	def clone(self) -> 'IqRecorder':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = IqRecorder(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GprfMeasurement:
	"""GprfMeasurement commands group definition. 120 total commands, 8 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("gprfMeasurement", core, parent)

	@property
	def spectrum(self):
		"""spectrum commands group. 6 Sub-classes, 5 commands."""
		if not hasattr(self, '_spectrum'):
			from .GprfMeasurement_.Spectrum import Spectrum
			self._spectrum = Spectrum(self._core, self._base)
		return self._spectrum

	@property
	def iqRecorder(self):
		"""iqRecorder commands group. 1 Sub-classes, 9 commands."""
		if not hasattr(self, '_iqRecorder'):
			from .GprfMeasurement_.IqRecorder import IqRecorder
			self._iqRecorder = IqRecorder(self._core, self._base)
		return self._iqRecorder

	@property
	def rfSettings(self):
		"""rfSettings commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_rfSettings'):
			from .GprfMeasurement_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	@property
	def extPwrSensor(self):
		"""extPwrSensor commands group. 2 Sub-classes, 6 commands."""
		if not hasattr(self, '_extPwrSensor'):
			from .GprfMeasurement_.ExtPwrSensor import ExtPwrSensor
			self._extPwrSensor = ExtPwrSensor(self._core, self._base)
		return self._extPwrSensor

	@property
	def nrt(self):
		"""nrt commands group. 3 Sub-classes, 10 commands."""
		if not hasattr(self, '_nrt'):
			from .GprfMeasurement_.Nrt import Nrt
			self._nrt = Nrt(self._core, self._base)
		return self._nrt

	@property
	def power(self):
		"""power commands group. 1 Sub-classes, 6 commands."""
		if not hasattr(self, '_power'):
			from .GprfMeasurement_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def fftSpecAn(self):
		"""fftSpecAn commands group. 2 Sub-classes, 9 commands."""
		if not hasattr(self, '_fftSpecAn'):
			from .GprfMeasurement_.FftSpecAn import FftSpecAn
			self._fftSpecAn = FftSpecAn(self._core, self._base)
		return self._fftSpecAn

	@property
	def acp(self):
		"""acp commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_acp'):
			from .GprfMeasurement_.Acp import Acp
			self._acp = Acp(self._core, self._base)
		return self._acp

	def get_crepetition(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:CREPetition \n
		Snippet: value: bool = driver.configure.gprfMeasurement.get_crepetition() \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:return: continuous_repetition: No help available
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:CREPetition?')
		return Conversions.str_to_bool(response)

	def set_crepetition(self, continuous_repetition: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:CREPetition \n
		Snippet: driver.configure.gprfMeasurement.set_crepetition(continuous_repetition = False) \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:param continuous_repetition: OFF | ON
		"""
		param = Conversions.bool_to_str(continuous_repetition)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:CREPetition {param}')

	def clone(self) -> 'GprfMeasurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GprfMeasurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BitErrorRate:
	"""BitErrorRate commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bitErrorRate", core, parent)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.Source:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:SOURce \n
		Snippet: value: enums.Source = driver.configure.afRf.measurement.data.bitErrorRate.get_source() \n
		Defines the input path for data to be analyzed. \n
			:return: source: TTLin
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.Source)

	def set_source(self, source: enums.Source) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:SOURce \n
		Snippet: driver.configure.afRf.measurement.data.bitErrorRate.set_source(source = enums.Source.TTLin) \n
		Defines the input path for data to be analyzed. \n
			:param source: TTLin
		"""
		param = Conversions.enum_scalar_to_str(source, enums.Source)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:SOURce {param}')

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.UserDefPattern:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:PATTern \n
		Snippet: value: enums.UserDefPattern = driver.configure.afRf.measurement.data.bitErrorRate.get_pattern() \n
		Selects the bit pattern to be transmitted as payload. \n
			:return: pattern: PRBS6 | PRBS9
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.UserDefPattern)

	def set_pattern(self, pattern: enums.UserDefPattern) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:PATTern \n
		Snippet: driver.configure.afRf.measurement.data.bitErrorRate.set_pattern(pattern = enums.UserDefPattern.PRBS6) \n
		Selects the bit pattern to be transmitted as payload. \n
			:param pattern: PRBS6 | PRBS9
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.UserDefPattern)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:PATTern {param}')

	def get_drate(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:DRATe \n
		Snippet: value: int = driver.configure.afRf.measurement.data.bitErrorRate.get_drate() \n
		The bit rate that is expected for the incoming data to be analyzed. \n
			:return: drate: Range: 0 bit/s to 115.2E+3 bit/s, Unit: bit/s
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:DRATe?')
		return Conversions.str_to_int(response)

	def get_ibits(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:IBITs \n
		Snippet: value: bool = driver.configure.afRf.measurement.data.bitErrorRate.get_ibits() \n
		If set to ON, each 0 in the bit sequence is turned to 1 and vice versa. \n
			:return: invert_bits: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:BERate:IBITs?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set_all(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:MARKer:ENABle:ALL \n
		Snippet: driver.configure.afRf.measurement.multiEval.fft.marker.enable.set_all(enable = False) \n
		Enables or disables the markers R, 2 and 3. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:FFT:MARKer:ENABle:ALL {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("select", core, parent)

	# noinspection PyTypeChecker
	class DstrategyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Arg_0: enums.OperationMode: No parameter help available
			- Arg_1: enums.Dstrategy: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Arg_0', enums.OperationMode),
			ArgStruct.scalar_enum('Arg_1', enums.Dstrategy)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Arg_0: enums.OperationMode = None
			self.Arg_1: enums.Dstrategy = None

	# noinspection PyTypeChecker
	def get_dstrategy(self) -> DstrategyStruct:
		"""SCPI: INSTrument[:SELect]:DSTRategy \n
		Snippet: value: DstrategyStruct = driver.instrument.select.get_dstrategy() \n
		No command help available \n
			:return: structure: for return value, see the help for DstrategyStruct structure arguments.
		"""
		return self._core.io.query_struct('INSTrument:SELect:DSTRategy?', self.__class__.DstrategyStruct())

	def set_dstrategy(self, value: DstrategyStruct) -> None:
		"""SCPI: INSTrument[:SELect]:DSTRategy \n
		Snippet: driver.instrument.select.set_dstrategy(value = DstrategyStruct()) \n
		No command help available \n
			:param value: see the help for DstrategyStruct structure arguments.
		"""
		self._core.io.write_struct('INSTrument:SELect:DSTRategy', value)

	def get_value(self) -> str:
		"""SCPI: INSTrument[:SELect] \n
		Snippet: value: str = driver.instrument.select.get_value() \n
		No command help available \n
			:return: instrument: No help available
		"""
		response = self._core.io.query_str('INSTrument:SELect?')
		return trim_str_response(response)

	def set_value(self, instrument: str) -> None:
		"""SCPI: INSTrument[:SELect] \n
		Snippet: driver.instrument.select.set_value(instrument = r1) \n
		No command help available \n
			:param instrument: No help available
		"""
		param = Conversions.value_to_str(instrument)
		self._core.io.write(f'INSTrument:SELect {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, freq_1: bool, frequencyLobe=repcap.FrequencyLobe.Default) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency<nr>:ENABle \n
		Snippet: driver.source.avionics.generator.ils.localizer.afSettings.frequency.enable.set(freq_1 = False, frequencyLobe = repcap.FrequencyLobe.Default) \n
		Enables or disables lobe number <no>. At least one lobe must be enabled. \n
			:param freq_1: OFF | ON
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')"""
		param = Conversions.bool_to_str(freq_1)
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency{frequencyLobe_cmd_val}:ENABle {param}')

	def get(self, frequencyLobe=repcap.FrequencyLobe.Default) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency<nr>:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.ils.localizer.afSettings.frequency.enable.get(frequencyLobe = repcap.FrequencyLobe.Default) \n
		Enables or disables lobe number <no>. At least one lobe must be enabled. \n
			:param frequencyLobe: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frequency')
			:return: freq_1: OFF | ON"""
		frequencyLobe_cmd_val = self._base.get_repcap_cmd_value(frequencyLobe, repcap.FrequencyLobe)
		response = self._core.io.query_str(f'SOURce:AVIonics:GENerator<Instance>:ILS:LOCalizer:AFSettings:FREQuency{frequencyLobe_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fdeviation:
	"""Fdeviation commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fdeviation", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.vor.afSettings.reference.fdeviation.get_enable() \n
		Enables or disables the modulation of the FM subcarrier with the REF signal. \n
			:return: vor_freq_deviation: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, vor_freq_deviation: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation:ENABle \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.fdeviation.set_enable(vor_freq_deviation = False) \n
		Enables or disables the modulation of the FM subcarrier with the REF signal. \n
			:param vor_freq_deviation: OFF | ON
		"""
		param = Conversions.bool_to_str(vor_freq_deviation)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation:ENABle {param}')

	def get_value(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.reference.fdeviation.get_value() \n
		Sets the frequency deviation of the REF signal on the FM subcarrier. \n
			:return: vor_freq_deviation: Range: 300 Hz to 600 Hz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation?')
		return Conversions.str_to_float(response)

	def set_value(self, vor_freq_deviation: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation \n
		Snippet: driver.source.avionics.generator.vor.afSettings.reference.fdeviation.set_value(vor_freq_deviation = 1.0) \n
		Sets the frequency deviation of the REF signal on the FM subcarrier. \n
			:param vor_freq_deviation: Range: 300 Hz to 600 Hz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(vor_freq_deviation)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:REFerence:FDEViation {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	# noinspection PyTypeChecker
	def get_bandwidth(self) -> enums.BandpassFilter:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FILTer:BWIDth \n
		Snippet: value: enums.BandpassFilter = driver.configure.afRf.measurement.multiEval.filterPy.get_bandwidth() \n
		Configures the bandwidth of the bandpass filter in the RF input path. \n
			:return: bandpass: F8330 | F25K | F50K | F01M | F05M Bandwidth 8330 Hz, 25 kHz, 50 kHz, 0.1 MHz, 0.5 MHz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:FILTer:BWIDth?')
		return Conversions.str_to_scalar_enum(response, enums.BandpassFilter)

	def set_bandwidth(self, bandpass: enums.BandpassFilter) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:FILTer:BWIDth \n
		Snippet: driver.configure.afRf.measurement.multiEval.filterPy.set_bandwidth(bandpass = enums.BandpassFilter.F01M) \n
		Configures the bandwidth of the bandpass filter in the RF input path. \n
			:param bandpass: F8330 | F25K | F50K | F01M | F05M Bandwidth 8330 Hz, 25 kHz, 50 kHz, 0.1 MHz, 0.5 MHz
		"""
		param = Conversions.enum_scalar_to_str(bandpass, enums.BandpassFilter)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:FILTer:BWIDth {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Self:
	"""Self commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("self", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ENABle \n
		Snippet: value: bool = driver.system.communicate.gpib.self.get_enable() \n
		Enables or disables the GPIB interface. \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:GPIB:SELF:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ENABle \n
		Snippet: driver.system.communicate.gpib.self.set_enable(enable = False) \n
		Enables or disables the GPIB interface. \n
			:param enable: 1 | 0 1: GPIB enabled 0: GPIB disabled
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SYSTem:COMMunicate:GPIB:SELF:ENABle {param}')

	def get_addr(self) -> int:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ADDR \n
		Snippet: value: int = driver.system.communicate.gpib.self.get_addr() \n
		Sets the primary GPIB address. \n
			:return: adress_no: GPIB address, integer number Range: 0 to 30
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:GPIB:SELF:ADDR?')
		return Conversions.str_to_int(response)

	def set_addr(self, adress_no: int) -> None:
		"""SCPI: SYSTem:COMMunicate:GPIB[:SELF]:ADDR \n
		Snippet: driver.system.communicate.gpib.self.set_addr(adress_no = 1) \n
		Sets the primary GPIB address. \n
			:param adress_no: GPIB address, integer number Range: 0 to 30
		"""
		param = Conversions.decimal_value_to_str(adress_no)
		self._core.io.write(f'SYSTem:COMMunicate:GPIB:SELF:ADDR {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsensitivity:
	"""Rsensitivity commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsensitivity", core, parent)

	# noinspection PyTypeChecker
	class RsLevelStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper limit for the RX sensitivity Range: -120 dBm to -100 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_rs_level(self) -> RsLevelStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSENsitivity:RSLevel \n
		Snippet: value: RsLevelStruct = driver.configure.afRf.measurement.searchRoutines.limit.rsensitivity.get_rs_level() \n
		Configures an upper limit for the measured RX sensitivity. \n
			:return: structure: for return value, see the help for RsLevelStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSENsitivity:RSLevel?', self.__class__.RsLevelStruct())

	def set_rs_level(self, value: RsLevelStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSENsitivity:RSLevel \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.rsensitivity.set_rs_level(value = RsLevelStruct()) \n
		Configures an upper limit for the measured RX sensitivity. \n
			:param value: see the help for RsLevelStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSENsitivity:RSLevel', value)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zigbee:
	"""Zigbee commands group definition. 9 total commands, 0 Sub-groups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zigbee", core, parent)

	def get_snumber(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SNUMber \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_snumber() \n
		No command help available \n
			:return: snum: Range: 0 to 255
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:SNUMber?')
		return trim_str_response(response)

	def set_snumber(self, snum: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SNUMber \n
		Snippet: driver.source.afRf.generator.zigbee.set_snumber(snum = r1) \n
		No command help available \n
			:param snum: Range: 0 to 255
		"""
		param = Conversions.value_to_str(snum)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:SNUMber {param}')

	def get_dpan(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:DPAN \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_dpan() \n
		No command help available \n
			:return: dpan: Range: 0 to 65.535E+3
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:DPAN?')
		return trim_str_response(response)

	def set_dpan(self, dpan: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:DPAN \n
		Snippet: driver.source.afRf.generator.zigbee.set_dpan(dpan = r1) \n
		No command help available \n
			:param dpan: Range: 0 to 65.535E+3
		"""
		param = Conversions.value_to_str(dpan)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:DPAN {param}')

	def get_daddress(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:DADDress \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_daddress() \n
		Configures the destination address, i.e. the DUT's address, to be signaled to the DUT, for ZigBee. \n
			:return: daddr: decimal Range: 0 to 65.535E+3
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:DADDress?')
		return trim_str_response(response)

	def set_daddress(self, daddr: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:DADDress \n
		Snippet: driver.source.afRf.generator.zigbee.set_daddress(daddr = r1) \n
		Configures the destination address, i.e. the DUT's address, to be signaled to the DUT, for ZigBee. \n
			:param daddr: decimal Range: 0 to 65.535E+3
		"""
		param = Conversions.value_to_str(daddr)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:DADDress {param}')

	def get_span(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SPAN \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_span() \n
		No command help available \n
			:return: span: Range: 0 to 65.535E+3
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:SPAN?')
		return trim_str_response(response)

	def set_span(self, span: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SPAN \n
		Snippet: driver.source.afRf.generator.zigbee.set_span(span = r1) \n
		No command help available \n
			:param span: Range: 0 to 65.535E+3
		"""
		param = Conversions.value_to_str(span)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:SPAN {param}')

	def get_saddress(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SADDress \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_saddress() \n
		No command help available \n
			:return: saddress: Range: 0 to 65.535E+3
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:SADDress?')
		return trim_str_response(response)

	def set_saddress(self, saddress: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SADDress \n
		Snippet: driver.source.afRf.generator.zigbee.set_saddress(saddress = r1) \n
		No command help available \n
			:param saddress: Range: 0 to 65.535E+3
		"""
		param = Conversions.value_to_str(saddress)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:SADDress {param}')

	def get_payload(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:PAYLoad \n
		Snippet: value: str = driver.source.afRf.generator.zigbee.get_payload() \n
		No command help available \n
			:return: payload: No help available
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:ZIGBee:PAYLoad?')
		return trim_str_response(response)

	def set_payload(self, payload: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:PAYLoad \n
		Snippet: driver.source.afRf.generator.zigbee.set_payload(payload = '1') \n
		No command help available \n
			:param payload: No help available
		"""
		param = Conversions.value_to_quoted_str(payload)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:ZIGBee:PAYLoad {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ZigBeeMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:MODE \n
		Snippet: value: enums.ZigBeeMode = driver.source.afRf.generator.zigbee.get_mode() \n
		No command help available \n
			:return: mode: OQPSk
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ZIGBee:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ZigBeeMode)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.zigbee.get_standard_dev() \n
		No command help available \n
			:return: sdeviation: Range: -180 deg to 180 deg, Unit: deg
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:AFRF:GENerator<Instance>:ZIGBee:SDEViation?')
		return response

	def get_symbol_rate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ZIGBee:SRATe \n
		Snippet: value: float = driver.source.afRf.generator.zigbee.get_symbol_rate() \n
		No command help available \n
			:return: srate: Range: 0 symbol/s to 1E+6 symbol/s, Unit: bit/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ZIGBee:SRATe?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bpass:
	"""Bpass commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bpass", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:ENABle \n
		Snippet: value: bool = driver.configure.afRf.measurement.voip.filterPy.bpass.get_enable() \n
		Enables or disables the variable bandpass filter in the VoIP input path. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:ENABle \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.bpass.set_enable(enable = False) \n
		Enables or disables the variable bandpass filter in the VoIP input path. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:ENABle {param}')

	def get_cfrequency(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:CFRequency \n
		Snippet: value: float = driver.configure.afRf.measurement.voip.filterPy.bpass.get_cfrequency() \n
		Configures the center frequency of the variable bandpass filter in the VoIP input path. \n
			:return: frequency: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:CFRequency?')
		return Conversions.str_to_float(response)

	def set_cfrequency(self, frequency: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:CFRequency \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.bpass.set_cfrequency(frequency = 1.0) \n
		Configures the center frequency of the variable bandpass filter in the VoIP input path. \n
			:param frequency: Range: 0 Hz to 21 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:CFRequency {param}')

	def get_bandwidth(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:BWIDth \n
		Snippet: value: float = driver.configure.afRf.measurement.voip.filterPy.bpass.get_bandwidth() \n
		Configures the bandwidth of the variable bandpass filter in the VoIP input path. \n
			:return: bandwidth: Range: 20 Hz to 20 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:BWIDth?')
		return Conversions.str_to_float(response)

	def set_bandwidth(self, bandwidth: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:BWIDth \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.bpass.set_bandwidth(bandwidth = 1.0) \n
		Configures the bandwidth of the variable bandpass filter in the VoIP input path. \n
			:param bandwidth: Range: 20 Hz to 20 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:BPASs:BWIDth {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, freq_counter_mode: enums.FreqCounterMode, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:COUNter:MODE \n
		Snippet: driver.configure.afRf.measurement.audioInput.counter.mode.set(freq_counter_mode = enums.FreqCounterMode.HW, audioInput = repcap.AudioInput.Default) \n
		Selects the type of frequency counter for measuring the AF frequency. \n
			:param freq_counter_mode: SW | HW Software or hardware implementation of the frequency counter
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(freq_counter_mode, enums.FreqCounterMode)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:COUNter:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.FreqCounterMode:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:COUNter:MODE \n
		Snippet: value: enums.FreqCounterMode = driver.configure.afRf.measurement.audioInput.counter.mode.get(audioInput = repcap.AudioInput.Default) \n
		Selects the type of frequency counter for measuring the AF frequency. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: freq_counter_mode: SW | HW Software or hardware implementation of the frequency counter"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:COUNter:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FreqCounterMode)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	# noinspection PyTypeChecker
	def get_language(self) -> enums.DisplayLanguage:
		"""SCPI: SYSTem:BASE:DISPlay:LANGuage \n
		Snippet: value: enums.DisplayLanguage = driver.system.base.display.get_language() \n
		Selects the GUI language to be used. The corresponding language and license must be installed. \n
			:return: language: AR | DE | SV | RU | KO | JA | EN | IT | FR | DA | ES | TR | CS | ZH
		"""
		response = self._core.io.query_str('SYSTem:BASE:DISPlay:LANGuage?')
		return Conversions.str_to_scalar_enum(response, enums.DisplayLanguage)

	def set_language(self, language: enums.DisplayLanguage) -> None:
		"""SCPI: SYSTem:BASE:DISPlay:LANGuage \n
		Snippet: driver.system.base.display.set_language(language = enums.DisplayLanguage.AR) \n
		Selects the GUI language to be used. The corresponding language and license must be installed. \n
			:param language: AR | DE | SV | RU | KO | JA | EN | IT | FR | DA | ES | TR | CS | ZH
		"""
		param = Conversions.enum_scalar_to_str(language, enums.DisplayLanguage)
		self._core.io.write(f'SYSTem:BASE:DISPlay:LANGuage {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cons:
	"""Cons commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cons", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Cons_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def iq(self):
		"""iq commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iq'):
			from .Cons_.Iq import Iq
			self._iq = Iq(self._core, self._base)
		return self._iq

	def clone(self) -> 'Cons':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Cons(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FftSpecAn:
	"""FftSpecAn commands group definition. 26 total commands, 7 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fftSpecAn", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .FftSpecAn_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .FftSpecAn_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	@property
	def peaks(self):
		"""peaks commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_peaks'):
			from .FftSpecAn_.Peaks import Peaks
			self._peaks = Peaks(self._core, self._base)
		return self._peaks

	@property
	def power(self):
		"""power commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_power'):
			from .FftSpecAn_.Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def qcomponent(self):
		"""qcomponent commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_qcomponent'):
			from .FftSpecAn_.Qcomponent import Qcomponent
			self._qcomponent = Qcomponent(self._core, self._base)
		return self._qcomponent

	@property
	def icomponent(self):
		"""icomponent commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_icomponent'):
			from .FftSpecAn_.Icomponent import Icomponent
			self._icomponent = Icomponent(self._core, self._base)
		return self._icomponent

	@property
	def tdomain(self):
		"""tdomain commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tdomain'):
			from .FftSpecAn_.Tdomain import Tdomain
			self._tdomain = Tdomain(self._core, self._base)
		return self._tdomain

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.initiate() \n
		Starts or continues the FFT spectrum analyzer. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.initiate_with_opc() \n
		Starts or continues the FFT spectrum analyzer. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.stop() \n
		Pauses the FFT spectrum analyzer. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.stop_with_opc() \n
		Pauses the FFT spectrum analyzer. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.abort() \n
		Stops the FFT spectrum analyzer. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:FFTSanalyzer \n
		Snippet: driver.gprfMeasurement.fftSpecAn.abort_with_opc() \n
		Stops the FFT spectrum analyzer. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:FFTSanalyzer')

	def clone(self) -> 'FftSpecAn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FftSpecAn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mlevel:
	"""Mlevel commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mlevel", core, parent)

	def set(self, max_level: float, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:MLEVel \n
		Snippet: driver.configure.afRf.measurement.audioInput.mlevel.set(max_level = 1.0, audioInput = repcap.AudioInput.Default) \n
		Specifies the maximum expected level for an AF IN connector in voltage-related units (Table 'Units relevant for remote
		commands') . This setting is only relevant, if auto ranging is disabled. The command sets the same unit for both AF IN
		connectors. If you want to set different level units (e.g. dBm) or set level for both connectors independently, use
		method RsCma.Configure.AfRf.Measurement.AudioInput.First.mlevel for AF1 IN and method RsCma.Configure.AfRf.Measurement.
		AudioInput.Second.mlevel for AF2 IN. \n
			:param max_level: Range: 10E-6 V to 43 V, Unit: V
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.decimal_value_to_str(max_level)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:MLEVel {param}')

	def get(self, audioInput=repcap.AudioInput.Default) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:MLEVel \n
		Snippet: value: float = driver.configure.afRf.measurement.audioInput.mlevel.get(audioInput = repcap.AudioInput.Default) \n
		Specifies the maximum expected level for an AF IN connector in voltage-related units (Table 'Units relevant for remote
		commands') . This setting is only relevant, if auto ranging is disabled. The command sets the same unit for both AF IN
		connectors. If you want to set different level units (e.g. dBm) or set level for both connectors independently, use
		method RsCma.Configure.AfRf.Measurement.AudioInput.First.mlevel for AF1 IN and method RsCma.Configure.AfRf.Measurement.
		AudioInput.Second.mlevel for AF2 IN. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: max_level: Range: 10E-6 V to 43 V, Unit: V"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:MLEVel?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Oscilloscope:
	"""Oscilloscope commands group definition. 35 total commands, 4 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("oscilloscope", core, parent)

	@property
	def demodulation(self):
		"""demodulation commands group. 4 Sub-classes, 7 commands."""
		if not hasattr(self, '_demodulation'):
			from .Oscilloscope_.Demodulation import Demodulation
			self._demodulation = Demodulation(self._core, self._base)
		return self._demodulation

	@property
	def audioInput(self):
		"""audioInput commands group. 0 Sub-classes, 8 commands."""
		if not hasattr(self, '_audioInput'):
			from .Oscilloscope_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdif(self):
		"""spdif commands group. 0 Sub-classes, 8 commands."""
		if not hasattr(self, '_spdif'):
			from .Oscilloscope_.Spdif import Spdif
			self._spdif = Spdif(self._core, self._base)
		return self._spdif

	@property
	def voip(self):
		"""voip commands group. 0 Sub-classes, 7 commands."""
		if not hasattr(self, '_voip'):
			from .Oscilloscope_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	# noinspection PyTypeChecker
	class TimeoutStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables the timeout
			- Timeout: float: Time interval during which a trigger event must occur Range: 0.2 s to 30 s, Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Timeout')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Timeout: float = None

	def get_timeout(self) -> TimeoutStruct:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:TOUT \n
		Snippet: value: TimeoutStruct = driver.trigger.afRf.measurement.multiEval.oscilloscope.get_timeout() \n
		Configures a timeout for the trigger modes 'Single' and 'Normal'. \n
			:return: structure: for return value, see the help for TimeoutStruct structure arguments.
		"""
		return self._core.io.query_struct('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:TOUT?', self.__class__.TimeoutStruct())

	def set_timeout(self, value: TimeoutStruct) -> None:
		"""SCPI: TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:TOUT \n
		Snippet: driver.trigger.afRf.measurement.multiEval.oscilloscope.set_timeout(value = TimeoutStruct()) \n
		Configures a timeout for the trigger modes 'Single' and 'Normal'. \n
			:param value: see the help for TimeoutStruct structure arguments.
		"""
		self._core.io.write_struct('TRIGger:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:TOUT', value)

	def clone(self) -> 'Oscilloscope':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Oscilloscope(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tgenerator:
	"""Tgenerator commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tgenerator", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:ENABle \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.tgenerator.get_enable() \n
		Enables the tracking mode, so that the generator application acts as tracking generator. \n
			:return: state: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, state: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:ENABle \n
		Snippet: driver.configure.gprfMeasurement.spectrum.tgenerator.set_enable(state = False) \n
		Enables the tracking mode, so that the generator application acts as tracking generator. \n
			:param state: OFF | ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:ENABle {param}')

	def get_normalize(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:NORMalize \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.tgenerator.get_normalize() \n
		Enables the normalization of the frequency sweep results for measurements with tracking generator. \n
			:return: normalize: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:NORMalize?')
		return Conversions.str_to_bool(response)

	def set_normalize(self, normalize: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:NORMalize \n
		Snippet: driver.configure.gprfMeasurement.spectrum.tgenerator.set_normalize(normalize = False) \n
		Enables the normalization of the frequency sweep results for measurements with tracking generator. \n
			:param normalize: OFF | ON
		"""
		param = Conversions.bool_to_str(normalize)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:TGENerator:NORMalize {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Measurement:
	"""Measurement commands group definition. 67 total commands, 10 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("measurement", core, parent)

	@property
	def dmr(self):
		"""dmr commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_dmr'):
			from .Measurement_.Dmr import Dmr
			self._dmr = Dmr(self._core, self._base)
		return self._dmr

	@property
	def dpmr(self):
		"""dpmr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dpmr'):
			from .Measurement_.Dpmr import Dpmr
			self._dpmr = Dpmr(self._core, self._base)
		return self._dpmr

	@property
	def nxdn(self):
		"""nxdn commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_nxdn'):
			from .Measurement_.Nxdn import Nxdn
			self._nxdn = Nxdn(self._core, self._base)
		return self._nxdn

	@property
	def ptFive(self):
		"""ptFive commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_ptFive'):
			from .Measurement_.PtFive import PtFive
			self._ptFive = PtFive(self._core, self._base)
		return self._ptFive

	@property
	def tetra(self):
		"""tetra commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_tetra'):
			from .Measurement_.Tetra import Tetra
			self._tetra = Tetra(self._core, self._base)
		return self._tetra

	@property
	def custom(self):
		"""custom commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_custom'):
			from .Measurement_.Custom import Custom
			self._custom = Custom(self._core, self._base)
		return self._custom

	@property
	def limit(self):
		"""limit commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .Measurement_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	@property
	def iqRecorder(self):
		"""iqRecorder commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_iqRecorder'):
			from .Measurement_.IqRecorder import IqRecorder
			self._iqRecorder = IqRecorder(self._core, self._base)
		return self._iqRecorder

	@property
	def xrt(self):
		"""xrt commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_xrt'):
			from .Measurement_.Xrt import Xrt
			self._xrt = Xrt(self._core, self._base)
		return self._xrt

	@property
	def result(self):
		"""result commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_result'):
			from .Measurement_.Result import Result
			self._result = Result(self._core, self._base)
		return self._result

	def get_crepetition(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:CREPetition \n
		Snippet: value: bool = driver.configure.vse.measurement.get_crepetition() \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:return: continuous_repetition: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:CREPetition?')
		return Conversions.str_to_bool(response)

	def set_crepetition(self, continuous_repetition: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:CREPetition \n
		Snippet: driver.configure.vse.measurement.set_crepetition(continuous_repetition = False) \n
		Enables or disables the automatic configuration of the repetition mode. With enabled automatic configuration, the
		repetition mode of all measurements is set to 'Continuous' each time the instrument switches from remote operation to
		manual operation. \n
			:param continuous_repetition: OFF | ON
		"""
		param = Conversions.bool_to_str(continuous_repetition)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:CREPetition {param}')

	def get_scount(self) -> int:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:SCOunt \n
		Snippet: value: int = driver.configure.vse.measurement.get_scount() \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval delivers a single 'Current'
		value per result. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:SCOunt \n
		Snippet: driver.configure.vse.measurement.set_scount(statistic_count = 1) \n
		Specifies the number of measurement intervals per measurement cycle. One measurement interval delivers a single 'Current'
		value per result. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:SCOunt {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.vse.measurement.get_repetition() \n
		Selects whether the measurement is repeated continuously or not. \n
			:return: repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after the statistic count CONTinuous Continuous measurement, running until explicitly terminated
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition: enums.Repeat) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:REPetition \n
		Snippet: driver.configure.vse.measurement.set_repetition(repetition = enums.Repeat.CONTinuous) \n
		Selects whether the measurement is repeated continuously or not. \n
			:param repetition: SINGleshot | CONTinuous SINGleshot Single-shot measurement, stopped after the statistic count CONTinuous Continuous measurement, running until explicitly terminated
		"""
		param = Conversions.enum_scalar_to_str(repetition, enums.Repeat)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:REPetition {param}')

	# noinspection PyTypeChecker
	def get_scondition(self) -> enums.StopCondition:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:SCONdition \n
		Snippet: value: enums.StopCondition = driver.configure.vse.measurement.get_scondition() \n
		Selects whether the measurement is stopped after a failed limit check or continued. \n
			:return: stop_condition: NONE | SLFail NONE Continue measurement irrespective of the limit check SLFail Stop measurement on limit failure
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:SCONdition?')
		return Conversions.str_to_scalar_enum(response, enums.StopCondition)

	def set_scondition(self, stop_condition: enums.StopCondition) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:SCONdition \n
		Snippet: driver.configure.vse.measurement.set_scondition(stop_condition = enums.StopCondition.NONE) \n
		Selects whether the measurement is stopped after a failed limit check or continued. \n
			:param stop_condition: NONE | SLFail NONE Continue measurement irrespective of the limit check SLFail Stop measurement on limit failure
		"""
		param = Conversions.enum_scalar_to_str(stop_condition, enums.StopCondition)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:SCONdition {param}')

	def get_rcoupling(self) -> bool:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RCOupling \n
		Snippet: value: bool = driver.configure.vse.measurement.get_rcoupling() \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:return: repetition_coupling: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:RCOupling?')
		return Conversions.str_to_bool(response)

	def set_rcoupling(self, repetition_coupling: bool) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:RCOupling \n
		Snippet: driver.configure.vse.measurement.set_rcoupling(repetition_coupling = False) \n
		Couples the repetition mode (single shot or continuous) of all measurements. \n
			:param repetition_coupling: OFF | ON
		"""
		param = Conversions.bool_to_str(repetition_coupling)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:RCOupling {param}')

	def get_timeout(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:TOUT \n
		Snippet: value: float = driver.configure.vse.measurement.get_timeout() \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:return: tcd_timeout: No help available
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:TOUT?')
		return Conversions.str_to_float(response)

	def set_timeout(self, tcd_timeout: float) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:TOUT \n
		Snippet: driver.configure.vse.measurement.set_timeout(tcd_timeout = 1.0) \n
		Defines a timeout for the measurement. The timer is started when the measurement is initiated via a READ or INIT command.
		It is not started if the measurement is initiated via the graphical user interface. The timer is reset after the first
		measurement cycle. If the first measurement cycle has not been completed when the timer expires, the measurement is
		stopped and the reliability indicator is set to 1. Still running READ, FETCh or CALCulate commands are completed,
		returning the available results. At least for some results, there are no values at all or the statistical depth has not
		been reached. A timeout of 0 s corresponds to an infinite measurement timeout. \n
			:param tcd_timeout: No help available
		"""
		param = Conversions.decimal_value_to_str(tcd_timeout)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:TOUT {param}')

	# noinspection PyTypeChecker
	def get_standard(self) -> enums.Standard:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:STANdard \n
		Snippet: value: enums.Standard = driver.configure.vse.measurement.get_standard() \n
		Selects the digital standard of the measured signal. The current software version supports only digital mobile radio
		(DMR) . \n
			:return: standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		response = self._core.io.query_str('CONFigure:VSE:MEASurement<Instance>:STANdard?')
		return Conversions.str_to_scalar_enum(response, enums.Standard)

	def set_standard(self, standard: enums.Standard) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:STANdard \n
		Snippet: driver.configure.vse.measurement.set_standard(standard = enums.Standard.CUSTom) \n
		Selects the digital standard of the measured signal. The current software version supports only digital mobile radio
		(DMR) . \n
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = Conversions.enum_scalar_to_str(standard, enums.Standard)
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:STANdard {param}')

	def clone(self) -> 'Measurement':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Measurement(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, tone_status: List[bool], internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:ENABle \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.enable.set(tone_status = [True, False, True], internalGen = repcap.InternalGen.Default) \n
		Enables or disables the tone list entries for multitone generation. \n
			:param tone_status: OFF | ON Comma-separated list of up to 20 values, tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list.
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.list_to_csv_str(tone_status)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:ENABle {param}')

	def get(self, internalGen=repcap.InternalGen.Default) -> List[bool]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:ENABle \n
		Snippet: value: List[bool] = driver.source.afRf.generator.internalGenerator.multiTone.enable.get(internalGen = repcap.InternalGen.Default) \n
		Enables or disables the tone list entries for multitone generation. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: tone_status: OFF | ON Comma-separated list of up to 20 values, tone 1 to tone 20 You can specify fewer than 20 values to configure only the beginning of the tone list."""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:ENABle?')
		return Conversions.str_to_bool_list(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Placement:
	"""Placement commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("placement", core, parent)

	def set(self, placement: enums.MarkerPlacement, markerOther=repcap.MarkerOther.Nr2) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:MARKer<nr>:PLACement \n
		Snippet: driver.configure.gprfMeasurement.spectrum.zeroSpan.marker.placement.set(placement = enums.MarkerPlacement.ABSolute, markerOther = repcap.MarkerOther.Nr2) \n
		Selects between absolute coordinates and coordinates relative to the reference marker, for marker number <no> and zero
		span mode. \n
			:param placement: ABSolute | RELative
			:param markerOther: optional repeated capability selector. Default value: Nr2"""
		param = Conversions.enum_scalar_to_str(placement, enums.MarkerPlacement)
		markerOther_cmd_val = self._base.get_repcap_cmd_value(markerOther, repcap.MarkerOther)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:MARKer{markerOther_cmd_val}:PLACement {param}')

	# noinspection PyTypeChecker
	def get(self, markerOther=repcap.MarkerOther.Nr2) -> enums.MarkerPlacement:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:MARKer<nr>:PLACement \n
		Snippet: value: enums.MarkerPlacement = driver.configure.gprfMeasurement.spectrum.zeroSpan.marker.placement.get(markerOther = repcap.MarkerOther.Nr2) \n
		Selects between absolute coordinates and coordinates relative to the reference marker, for marker number <no> and zero
		span mode. \n
			:param markerOther: optional repeated capability selector. Default value: Nr2
			:return: placement: ABSolute | RELative"""
		markerOther_cmd_val = self._base.get_repcap_cmd_value(markerOther, repcap.MarkerOther)
		response = self._core.io.query_str(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:ZSPan:MARKer{markerOther_cmd_val}:PLACement?')
		return Conversions.str_to_scalar_enum(response, enums.MarkerPlacement)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Display:
	"""Display commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("display", core, parent)

	def get_update(self) -> bool:
		"""SCPI: SYSTem:DISPlay:UPDate \n
		Snippet: value: bool = driver.system.display.get_update() \n
		Defines whether the display is updated or not while the instrument is in the remote state. Disabling the update speeds up
		testing and is the recommended state. See also 'Using the Display during Remote Control'. \n
			:return: display_update: No help available
		"""
		response = self._core.io.query_str('SYSTem:DISPlay:UPDate?')
		return Conversions.str_to_bool(response)

	def set_update(self, display_update: bool) -> None:
		"""SCPI: SYSTem:DISPlay:UPDate \n
		Snippet: driver.system.display.set_update(display_update = False) \n
		Defines whether the display is updated or not while the instrument is in the remote state. Disabling the update speeds up
		testing and is the recommended state. See also 'Using the Display during Remote Control'. \n
			:param display_update: 1 | 0 1: The display is shown and updated during remote control. 0: The display shows static image during remote control.
		"""
		param = Conversions.bool_to_str(display_update)
		self._core.io.write(f'SYSTem:DISPlay:UPDate {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CtCss:
	"""CtCss commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ctCss", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.tones.ctCss.get_enable() \n
		Enables or disables the CTCSS tone. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:ENABle \n
		Snippet: driver.source.afRf.generator.tones.ctCss.set_enable(enable = False) \n
		Enables or disables the CTCSS tone. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:ENABle {param}')

	def get_tnumber(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:TNUMber \n
		Snippet: value: int = driver.source.afRf.generator.tones.ctCss.get_tnumber() \n
		Selects a CTCSS tone via its number in the tone list. \n
			:return: tone_number: Range: 1 to 50
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:TNUMber?')
		return Conversions.str_to_int(response)

	def set_tnumber(self, tone_number: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:TNUMber \n
		Snippet: driver.source.afRf.generator.tones.ctCss.set_tnumber(tone_number = 1) \n
		Selects a CTCSS tone via its number in the tone list. \n
			:param tone_number: Range: 1 to 50
		"""
		param = Conversions.decimal_value_to_str(tone_number)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:CTCSs:TNUMber {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SearchRoutines:
	"""SearchRoutines commands group definition. 82 total commands, 6 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("searchRoutines", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .SearchRoutines_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def rsensitivity(self):
		"""rsensitivity commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_rsensitivity'):
			from .SearchRoutines_.Rsensitivity import Rsensitivity
			self._rsensitivity = Rsensitivity(self._core, self._base)
		return self._rsensitivity

	@property
	def rifBandwidth(self):
		"""rifBandwidth commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_rifBandwidth'):
			from .SearchRoutines_.RifBandwidth import RifBandwidth
			self._rifBandwidth = RifBandwidth(self._core, self._base)
		return self._rifBandwidth

	@property
	def rsquelch(self):
		"""rsquelch commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_rsquelch'):
			from .SearchRoutines_.Rsquelch import Rsquelch
			self._rsquelch = Rsquelch(self._core, self._base)
		return self._rsquelch

	@property
	def ssnr(self):
		"""ssnr commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ssnr'):
			from .SearchRoutines_.Ssnr import Ssnr
			self._ssnr = Ssnr(self._core, self._base)
		return self._ssnr

	@property
	def tsensitivity(self):
		"""tsensitivity commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_tsensitivity'):
			from .SearchRoutines_.Tsensitivity import Tsensitivity
			self._tsensitivity = Tsensitivity(self._core, self._base)
		return self._tsensitivity

	def initiate(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.initiate() \n
		Starts or continues the search routine. \n
		"""
		self._core.io.write(f'INITiate:AFRF:MEASurement<Instance>:SROutines')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.initiate_with_opc() \n
		Starts or continues the search routine. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:AFRF:MEASurement<Instance>:SROutines')

	def stop(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.stop() \n
		Pauses the search routine. \n
		"""
		self._core.io.write(f'STOP:AFRF:MEASurement<Instance>:SROutines')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.stop_with_opc() \n
		Pauses the search routine. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:AFRF:MEASurement<Instance>:SROutines')

	def abort(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.abort() \n
		Stops the search routine. \n
		"""
		self._core.io.write(f'ABORt:AFRF:MEASurement<Instance>:SROutines')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:SROutines \n
		Snippet: driver.afRf.measurement.searchRoutines.abort_with_opc() \n
		Stops the search routine. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:AFRF:MEASurement<Instance>:SROutines')

	def clone(self) -> 'SearchRoutines':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SearchRoutines(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RfSettings:
	"""RfSettings commands group definition. 4 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rfSettings", core, parent)

	@property
	def rfOut(self):
		"""rfOut commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rfOut'):
			from .RfSettings_.RfOut import RfOut
			self._rfOut = RfOut(self._core, self._base)
		return self._rfOut

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:FREQuency \n
		Snippet: value: float = driver.source.avionics.generator.ils.gslope.rfSettings.get_frequency() \n
		Specifies the center frequency of the unmodulated RF carrier for the glide slope signal. \n
			:return: freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:FREQuency \n
		Snippet: driver.source.avionics.generator.ils.gslope.rfSettings.set_frequency(freq = 1.0) \n
		Specifies the center frequency of the unmodulated RF carrier for the glide slope signal. \n
			:param freq: Range: 100 kHz to 3 GHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:FREQuency {param}')

	# noinspection PyTypeChecker
	class ChannelStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Channel: int: Channel number Range: 18 to 56
			- Letter: enums.IlsLetter: X | Y Channel letter"""
		__meta_args_list = [
			ArgStruct.scalar_int('Channel'),
			ArgStruct.scalar_enum('Letter', enums.IlsLetter)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Channel: int = None
			self.Letter: enums.IlsLetter = None

	def get_channel(self) -> ChannelStruct:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:CHANnel \n
		Snippet: value: ChannelStruct = driver.source.avionics.generator.ils.gslope.rfSettings.get_channel() \n
		Selects the RF channel. Each channel is identified via a number and a letter, for example 18X. \n
			:return: structure: for return value, see the help for ChannelStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:CHANnel?', self.__class__.ChannelStruct())

	def set_channel(self, value: ChannelStruct) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:CHANnel \n
		Snippet: driver.source.avionics.generator.ils.gslope.rfSettings.set_channel(value = ChannelStruct()) \n
		Selects the RF channel. Each channel is identified via a number and a letter, for example 18X. \n
			:param value: see the help for ChannelStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:CHANnel', value)

	def get_level(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:LEVel \n
		Snippet: value: float = driver.source.avionics.generator.ils.gslope.rfSettings.get_level() \n
		Specifies the RMS level of the unmodulated RF carrier. The allowed range depends on several other settings, for example
		on the selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the
		data sheet. \n
			:return: level: Unit: dBm
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:LEVel \n
		Snippet: driver.source.avionics.generator.ils.gslope.rfSettings.set_level(level = 1.0) \n
		Specifies the RMS level of the unmodulated RF carrier. The allowed range depends on several other settings, for example
		on the selected connector, the frequency and the external attenuation. For supported output level ranges, refer to the
		data sheet. \n
			:param level: Unit: dBm
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:ILS:GSLope:RFSettings:LEVel {param}')

	def clone(self) -> 'RfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = RfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Modulator:
	"""Modulator commands group definition. 9 total commands, 1 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("modulator", core, parent)

	@property
	def fmStereo(self):
		"""fmStereo commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_fmStereo'):
			from .Modulator_.FmStereo import FmStereo
			self._fmStereo = FmStereo(self._core, self._base)
		return self._fmStereo

	def get_fdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:FDEViation \n
		Snippet: value: float = driver.source.afRf.generator.modulator.get_fdeviation() \n
		Specifies the maximum frequency deviation for the FM modulation scheme. \n
			:return: freq_deviation: Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MODulator:FDEViation?')
		return Conversions.str_to_float(response)

	def set_fdeviation(self, freq_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:FDEViation \n
		Snippet: driver.source.afRf.generator.modulator.set_fdeviation(freq_deviation = 1.0) \n
		Specifies the maximum frequency deviation for the FM modulation scheme. \n
			:param freq_deviation: Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MODulator:FDEViation {param}')

	def get_pdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:PDEViation \n
		Snippet: value: float = driver.source.afRf.generator.modulator.get_pdeviation() \n
		Specifies the maximum phase deviation for the PM modulation scheme. \n
			:return: phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MODulator:PDEViation?')
		return Conversions.str_to_float(response)

	def set_pdeviation(self, phase_deviation: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:PDEViation \n
		Snippet: driver.source.afRf.generator.modulator.set_pdeviation(phase_deviation = 1.0) \n
		Specifies the maximum phase deviation for the PM modulation scheme. \n
			:param phase_deviation: Range: 0 rad to 10 rad, Unit: rad
		"""
		param = Conversions.decimal_value_to_str(phase_deviation)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MODulator:PDEViation {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:MDEPth \n
		Snippet: value: float = driver.source.afRf.generator.modulator.get_mod_depth() \n
		Specifies the modulation depth for the AM modulation scheme. \n
			:return: modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MODulator:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, modulation_depth: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:MDEPth \n
		Snippet: driver.source.afRf.generator.modulator.set_mod_depth(modulation_depth = 1.0) \n
		Specifies the modulation depth for the AM modulation scheme. \n
			:param modulation_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(modulation_depth)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MODulator:MDEPth {param}')

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Left: bool: OFF | ON
			- Right: bool: OFF | ON"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Left'),
			ArgStruct.scalar_bool('Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Left: bool = None
			self.Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:ENABle \n
		Snippet: value: EnableStruct = driver.source.afRf.generator.modulator.get_enable() \n
		Enables or disables the audio signal input paths of the modulator. For FM stereo, the settings configure the left and the
		right audio channel. For other modulation types, only <Left> is relevant. <Right> has no effect. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce:AFRF:GENerator<Instance>:MODulator:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:ENABle \n
		Snippet: driver.source.afRf.generator.modulator.set_enable(value = EnableStruct()) \n
		Enables or disables the audio signal input paths of the modulator. For FM stereo, the settings configure the left and the
		right audio channel. For other modulation types, only <Left> is relevant. <Right> has no effect. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('SOURce:AFRF:GENerator<Instance>:MODulator:ENABle', value)

	# noinspection PyTypeChecker
	def get_value(self) -> enums.SignalSource:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator \n
		Snippet: value: enums.SignalSource = driver.source.afRf.generator.modulator.get_value() \n
		Selects the source of an audio signal to be transported via the RF carrier. \n
			:return: modulator_source: GEN3 | GEN4 | GENB | AFI1 | AFI2 | AFIB | SPIL | SPIR | SPIN GEN3 Audio generator 3 GEN4 Audio generator 4 GENB Audio generator 3 and 4 AFI1 AF1 IN AFI2 AF2 IN AFIB AF1 IN and AF2 IN SPIL SPDIF IN, left channel SPIR SPDIF IN, right channel SPIN SPDIF IN, both channels
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MODulator?')
		return Conversions.str_to_scalar_enum(response, enums.SignalSource)

	def set_value(self, modulator_source: enums.SignalSource) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator \n
		Snippet: driver.source.afRf.generator.modulator.set_value(modulator_source = enums.SignalSource.AFI1) \n
		Selects the source of an audio signal to be transported via the RF carrier. \n
			:param modulator_source: GEN3 | GEN4 | GENB | AFI1 | AFI2 | AFIB | SPIL | SPIR | SPIN GEN3 Audio generator 3 GEN4 Audio generator 4 GENB Audio generator 3 and 4 AFI1 AF1 IN AFI2 AF2 IN AFIB AF1 IN and AF2 IN SPIL SPDIF IN, left channel SPIR SPDIF IN, right channel SPIN SPDIF IN, both channels
		"""
		param = Conversions.enum_scalar_to_str(modulator_source, enums.SignalSource)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:MODulator {param}')

	def clone(self) -> 'Modulator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Modulator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, tone_status: bool, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:TONE:ALL:ENABle \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.tone.all.enable.set(tone_status = False, internalGen = repcap.InternalGen.Default) \n
		Enables or disables all tone list entries for multitone generation. \n
			:param tone_status: OFF | ON
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.bool_to_str(tone_status)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:TONE:ALL:ENABle {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Update:
	"""Update commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("update", core, parent)

	def set(self, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FREQuency:DELTa:UPDate \n
		Snippet: driver.configure.afRf.measurement.audioInput.frequency.delta.update.set(audioInput = repcap.AudioInput.Default) \n
		No command help available \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FREQuency:DELTa:UPDate')

	def set_with_opc(self, audioInput=repcap.AudioInput.Default) -> None:
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FREQuency:DELTa:UPDate \n
		Snippet: driver.configure.afRf.measurement.audioInput.frequency.delta.update.set_with_opc(audioInput = repcap.AudioInput.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		self._core.io.write_with_opc(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FREQuency:DELTa:UPDate')



from typing import List

from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions
from ..Internal.Types import DataType
from ..Internal.Utilities import trim_str_response
from ..Internal.ArgSingleList import ArgSingleList
from ..Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MassMemory:
	"""MassMemory commands group definition. 17 total commands, 6 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("massMemory", core, parent)

	@property
	def attribute(self):
		"""attribute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_attribute'):
			from .MassMemory_.Attribute import Attribute
			self._attribute = Attribute(self._core, self._base)
		return self._attribute

	@property
	def catalog(self):
		"""catalog commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .MassMemory_.Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	@property
	def currentDirectory(self):
		"""currentDirectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_currentDirectory'):
			from .MassMemory_.CurrentDirectory import CurrentDirectory
			self._currentDirectory = CurrentDirectory(self._core, self._base)
		return self._currentDirectory

	@property
	def dcatalog(self):
		"""dcatalog commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_dcatalog'):
			from .MassMemory_.Dcatalog import Dcatalog
			self._dcatalog = Dcatalog(self._core, self._base)
		return self._dcatalog

	@property
	def load(self):
		"""load commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_load'):
			from .MassMemory_.Load import Load
			self._load = Load(self._core, self._base)
		return self._load

	@property
	def store(self):
		"""store commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_store'):
			from .MassMemory_.Store import Store
			self._store = Store(self._core, self._base)
		return self._store

	def copy(self, file_source: str, file_destination: str = None) -> None:
		"""SCPI: MMEMory:COPY \n
		Snippet: driver.massMemory.copy(file_source = '1', file_destination = '1') \n
		Copies an existing file. The target directory must exist. \n
			:param file_source: String parameter to specify the name of the file to be copied. Wildcards ? and * are allowed if FileDestination contains a path without file name.
			:param file_destination: String parameter to specify the path and/or name of the new file. If the parameter is omitted, the new file is written to the current directory (see method RsCma.MassMemory.CurrentDirectory.set) .
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('file_source', file_source, DataType.String), ArgSingle('file_destination', file_destination, DataType.String, True))
		self._core.io.write(f'MMEMory:COPY {param}'.rstrip())

	def delete(self, filename: str) -> None:
		"""SCPI: MMEMory:DELete \n
		Snippet: driver.massMemory.delete(filename = '1') \n
		Deletes the specified files. \n
			:param filename: String parameter to specify the file to be deleted. The wildcards * and ? are allowed. Specifying a directory instead of a file is not allowed.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'MMEMory:DELete {param}')

	def get_drives(self) -> List[str]:
		"""SCPI: MMEMory:DRIVes \n
		Snippet: value: List[str] = driver.massMemory.get_drives() \n
		Returns a list of the drives of the instrument. \n
			:return: drive: No help available
		"""
		response = self._core.io.query_str('MMEMory:DRIVes?')
		return Conversions.str_to_str_list(response)

	def make_directory(self, directory_name: str) -> None:
		"""SCPI: MMEMory:MDIRectory \n
		Snippet: driver.massMemory.make_directory(directory_name = '1') \n
		Creates a directory. \n
			:param directory_name: String parameter to specify the new directory. All not yet existing parts of the specified path are created.
		"""
		param = Conversions.value_to_quoted_str(directory_name)
		self._core.io.write(f'MMEMory:MDIRectory {param}')

	def move(self, file_source: str, file_destination: str) -> None:
		"""SCPI: MMEMory:MOVE \n
		Snippet: driver.massMemory.move(file_source = '1', file_destination = '1') \n
		Moves an existing object (file or directory) to a new location and renames it. \n
			:param file_source: String parameter to specify the name of the object to be moved or renamed. Wildcards ? and * are allowed if the files are not renamed.
			:param file_destination: String parameter to specify the new name and/or path of the object. New object name without path: The object is renamed. New path without object name: The object is moved. New path and new object name: The object is moved and renamed.
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('file_source', file_source, DataType.String), ArgSingle('file_destination', file_destination, DataType.String))
		self._core.io.write(f'MMEMory:MOVE {param}'.rstrip())

	def get_msis(self) -> str:
		"""SCPI: MMEMory:MSIS \n
		Snippet: value: str = driver.massMemory.get_msis() \n
		Sets the default storage unit to the specified drive or network server. When the default storage unit is changed, the R&S
		CMA180 checks whether the current directory (see method RsCma.MassMemory.CurrentDirectory.set) is also available on the
		new storage unit. If not, the current directory is automatically set to '/'. \n
			:return: msus: No help available
		"""
		response = self._core.io.query_str('MMEMory:MSIS?')
		return trim_str_response(response)

	def set_msis(self, msus: str) -> None:
		"""SCPI: MMEMory:MSIS \n
		Snippet: driver.massMemory.set_msis(msus = '1') \n
		Sets the default storage unit to the specified drive or network server. When the default storage unit is changed, the R&S
		CMA180 checks whether the current directory (see method RsCma.MassMemory.CurrentDirectory.set) is also available on the
		new storage unit. If not, the current directory is automatically set to '/'. \n
			:param msus: String parameter to specify the default storage unit. If the parameter is omitted, the storage unit is set to D:.
		"""
		param = Conversions.value_to_quoted_str(msus)
		self._core.io.write(f'MMEMory:MSIS {param}')

	def delete_directory(self, directory_name: str) -> None:
		"""SCPI: MMEMory:RDIRectory \n
		Snippet: driver.massMemory.delete_directory(directory_name = '1') \n
		Deletes an existing empty directory. \n
			:param directory_name: String parameter to specify the directory.
		"""
		param = Conversions.value_to_quoted_str(directory_name)
		self._core.io.write(f'MMEMory:RDIRectory {param}')

	def clone(self) -> 'MassMemory':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MassMemory(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tones:
	"""Tones commands group definition. 9 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tones", core, parent)

	@property
	def scal(self):
		"""scal commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_scal'):
			from .Tones_.Scal import Scal
			self._scal = Scal(self._core, self._base)
		return self._scal

	@property
	def dcs(self):
		"""dcs commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_dcs'):
			from .Tones_.Dcs import Dcs
			self._dcs = Dcs(self._core, self._base)
		return self._dcs

	# noinspection PyTypeChecker
	class DigPauseStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower pause limit Range: -100 % to 0 %, Unit: %
			- Upper: float: Upper pause limit Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_dig_pause(self) -> DigPauseStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGPause \n
		Snippet: value: DigPauseStruct = driver.configure.afRf.measurement.multiEval.limit.tones.get_dig_pause() \n
		Configures limits for the pause between two tones of an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:return: structure: for return value, see the help for DigPauseStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGPause?', self.__class__.DigPauseStruct())

	def set_dig_pause(self, value: DigPauseStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGPause \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.set_dig_pause(value = DigPauseStruct()) \n
		Configures limits for the pause between two tones of an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:param value: see the help for DigPauseStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGPause', value)

	# noinspection PyTypeChecker
	class DigtimeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower digit-duration limit Range: -100 % to 0 %, Unit: %
			- Upper: float: Upper digit-duration limit Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_digtime(self) -> DigtimeStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGTime \n
		Snippet: value: DigtimeStruct = driver.configure.afRf.measurement.multiEval.limit.tones.get_digtime() \n
		Configures limits for the digit duration in an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:return: structure: for return value, see the help for DigtimeStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGTime?', self.__class__.DigtimeStruct())

	def set_digtime(self, value: DigtimeStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGTime \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.set_digtime(value = DigtimeStruct()) \n
		Configures limits for the digit duration in an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:param value: see the help for DigtimeStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:DIGTime', value)

	# noinspection PyTypeChecker
	class FdeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower frequency-deviation limit Range: -100 % to 0 %, Unit: %
			- Upper: float: Upper frequency-deviation limit Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_fdeviation(self) -> FdeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:FDEViation \n
		Snippet: value: FdeviationStruct = driver.configure.afRf.measurement.multiEval.limit.tones.get_fdeviation() \n
		Configures limits for the frequency deviation of tones in an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:return: structure: for return value, see the help for FdeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:FDEViation?', self.__class__.FdeviationStruct())

	def set_fdeviation(self, value: FdeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:FDEViation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.tones.set_fdeviation(value = FdeviationStruct()) \n
		Configures limits for the frequency deviation of tones in an analyzed tone sequence (DTMF, free dialing and SelCall) . \n
			:param value: see the help for FdeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:TONes:FDEViation', value)

	def clone(self) -> 'Tones':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tones(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delta:
	"""Delta commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("delta", core, parent)

	# noinspection PyTypeChecker
	class UserStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Left_User_Val: float: Unit: Hz
			- Right_User_Val: float: Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Left_User_Val'),
			ArgStruct.scalar_float('Right_User_Val')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Left_User_Val: float = None
			self.Right_User_Val: float = None

	def get_user(self) -> UserStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:USER \n
		Snippet: value: UserStruct = driver.configure.afRf.measurement.demodulation.fmStereo.frequency.delta.get_user() \n
		No command help available \n
			:return: structure: for return value, see the help for UserStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:USER?', self.__class__.UserStruct())

	def set_user(self, value: UserStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:USER \n
		Snippet: driver.configure.afRf.measurement.demodulation.fmStereo.frequency.delta.set_user(value = UserStruct()) \n
		No command help available \n
			:param value: see the help for UserStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:USER', value)

	# noinspection PyTypeChecker
	class MeasuredStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Left_Meas_Val: float: Unit: Hz
			- Right_Meas_Val: float: Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Left_Meas_Val'),
			ArgStruct.scalar_float('Right_Meas_Val')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Left_Meas_Val: float = None
			self.Right_Meas_Val: float = None

	def get_measured(self) -> MeasuredStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:MEASured \n
		Snippet: value: MeasuredStruct = driver.configure.afRf.measurement.demodulation.fmStereo.frequency.delta.get_measured() \n
		No command help available \n
			:return: structure: for return value, see the help for MeasuredStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FMSTereo:FREQuency:DELTa:MEASured?', self.__class__.MeasuredStruct())
